==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/plugins/cpptools/cppcodestylepreferencesfactory.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef CPPCODESTYLEPREFERENCESFACTORY_H
#define CPPCODESTYLEPREFERENCESFACTORY_H

#include <texteditor/icodestylepreferencesfactory.h>

namespace CppTools {

class CppCodeStylePreferencesFactory : public TextEditor::ICodeStylePreferencesFactory
{
public:
    CppCodeStylePreferencesFactory();

    Core::Id languageId();
    QString displayName();
    TextEditor::ICodeStylePreferences *createCodeStyle() const;
    QWidget *createEditor(TextEditor::ICodeStylePreferences *settings,
                          QWidget *parent) const;
    TextEditor::Indenter *createIndenter() const;
    TextEditor::ISnippetProvider *snippetProvider() const;
    QString previewText() const;
};

} // namespace CppTools

#endif // CPPCODESTYLEPREFERENCESFACTORY_H

==> qt-creator-opensource-src-4.7.1.zip: qt-creator-opensource-src-4.7.1/src/plugins/cpptools/cppcodestylepreferencesfactory.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <texteditor/icodestylepreferencesfactory.h>

namespace CppTools {

class CppCodeStylePreferencesFactory : public TextEditor::ICodeStylePreferencesFactory
{
public:
    CppCodeStylePreferencesFactory();

    Core::Id languageId();
    QString displayName();
    TextEditor::ICodeStylePreferences *createCodeStyle() const;
    QWidget *createEditor(TextEditor::ICodeStylePreferences *settings,
                          QWidget *parent) const;
    TextEditor::Indenter *createIndenter() const;
    QString snippetProviderGroupId() const;
    QString previewText() const;
};

} // namespace CppTools
